============
unisos.utils
============

.. contents::
   :depth: 3
..

Overview
========

unisos.utils: General purpose python utilities at unisos layer. (shRun,
etc.)

shRun is an adoption of invoke.run for ICMs.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Installation
============

::

    sudo pip install unisos.utils

Usage
=====

::

    from unisos.utils import shRun

::

    ./bin/icmShRunExample.py
